client

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 4, 2022 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client provides methods for making REST requests.

func New

func New(timeout time.Duration) Client

New creates a new Client instance.

func (Client) Delete

func (c Client) Delete(ctx context.Context, request HTTPRequest) (HTTPResult, error)

Delete execute a http DELETE method with application/json headers.

func (Client) Get

func (c Client) Get(ctx context.Context, request HTTPRequest) (HTTPResult, error)

Get execute a http GET method.

func (Client) Patch

func (c Client) Patch(ctx context.Context, request HTTPRequest) (rst HTTPResult, err error)

Patch execute a http PATCH method with application/json headers.

func (Client) Post

func (c Client) Post(ctx context.Context, request HTTPRequest) (HTTPResult, error)

Post execute a http POST method with application/json headers.

func (Client) Put

func (c Client) Put(ctx context.Context, request HTTPRequest) (rst HTTPResult, err error)

Put execute a http PUT method with application/json headers.

type HTTPHeaders

type HTTPHeaders map[string]string

HTTPHeaders is a map containing the relation key=value of the headers used on the http rest request.

type HTTPQueryParams

type HTTPQueryParams map[string]string

HTTPQueryParams is a map containing the relation key=value of the query params used on the http rest request

type HTTPRequest

type HTTPRequest struct {
	URL         string
	Body        []byte
	Headers     HTTPHeaders
	QueryParams HTTPQueryParams
}

HTTPRequest are the params used to build a new http rest request

type HTTPResult

type HTTPResult struct {
	StatusCode int
	Response   []byte
}

HTTPResult are the params returned from the client HTTP request

Jump to